# The Lector Experience
![npm-size](https://img.shields.io/npm/v/lectorjs?style=flat-square)
![npm-size](https://img.shields.io/npm/l/lectorjs?style=flat-square)
![npm-size](https://img.shields.io/github/commit-activity/m/robo-monk/lector?style=flat-square)
![npm-size](https://img.shields.io/npm/dw/lectorjs?style=flat-square)

### [ 🚀 Demo ](https://robo-monk.github.io/lector)

Hi


## First time:

```bash
git clone git@github.com:robo-monk/lector.git
cd __pkg__
yarn install
```
* Python 3 required (prefferably installed with `brew`)
* virtualenv (`pip install virtualenv`)

## Run this to compile the code when you make changes:

Depends on your package manager (my recommendation would be `yarn`)

```bash
source setup yarn
```

```bash
source setup npm
```

# Install

### Use npm or yarn:
```bash
yarn install __pkg__
```

## Set up

Blah